summaryrefslogtreecommitdiff
path: root/lib/rmdir.c
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2005-06-02 05:05:29 +0000
committerPaul Eggert <eggert@cs.ucla.edu>2005-06-02 05:05:29 +0000
commitab2edb9e3307a172487bb16edcaf79600bf9ebea (patch)
tree891357990f461f806713fa4cb52c1b9bb91d1ba3 /lib/rmdir.c
parent1e6b9bd047bdaf17291f87e44a218814dd6560f5 (diff)
downloadcoreutils-ab2edb9e3307a172487bb16edcaf79600bf9ebea.tar.xz
Don't use "path" or "filename" to mean "file name"
in comments or local variable names.
Diffstat (limited to 'lib/rmdir.c')
-rw-r--r--lib/rmdir.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/lib/rmdir.c b/lib/rmdir.c
index 73d8e4339..ad026a641 100644
--- a/lib/rmdir.c
+++ b/lib/rmdir.c
@@ -1,6 +1,7 @@
/* BSD compatible remove directory function for System V
- Copyright (C) 1988, 1990, 1999, 2003, 2004 Free Software Foundation, Inc.
+ Copyright (C) 1988, 1990, 1999, 2003, 2004, 2005 Free Software
+ Foundation, Inc.
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -28,17 +29,17 @@
/* rmdir adapted from GNU tar. */
/* Remove directory DPATH.
Return 0 if successful, -1 if not. */
int
-rmdir (char const *dpath)
+rmdir (char const *dir)
{
pid_t cpid;
int status;
struct stat statbuf;
- if (stat (dpath, &statbuf) != 0)
+ if (stat (dir, &statbuf) != 0)
return -1; /* errno already set */
if (!S_ISDIR (statbuf.st_mode))
@@ -54,7 +55,7 @@ rmdir (char const *dpath)
return -1; /* errno already set */
case 0: /* child process */
- execl ("/bin/rmdir", "rmdir", dpath, (char *) 0);
+ execl ("/bin/rmdir", "rmdir", dir, (char *) 0);
_exit (1);
default: /* parent process */
@@ -28,17 +29,17 @@
/* rmdir adapted from GNU tar. */
-/* Remove directory DPATH.
+/* Remove directory DIR.
Return 0 if successful, -1 if not. */
int